@@ -209,7 +209,9 @@
       "exponential" = NA
     )
   } else {
-    skewness <- moments::skewness(samples)
+    # See Joanes, D. N.; Gill, C. A. (1998). Comparing measures of sample skewness and kurtosis. Journal of the Royal Statistical Society, Series D. 47(1): 183–189.
+    # The formula below is taken from the 'skewness()' function in the 'moments' package.
+    skewness <- (sum((samples - mean(samples))^3) / length(samples)) / (sum((samples - mean(samples))^2) / length(samples))^(3 / 2)
   }
   return(skewness)
 }
@@ -240,34 +242,6 @@
   return(entropy)
 }
 
-.comp_kl_bayes <- function(family, prior_alpha, prior_beta, post_alpha, post_beta, analytical = TRUE, samples_prior = NULL, samples_post = NULL) {
-  if (analytical) {
-    if (prior_alpha == 0 || prior_beta == 0) {
-      kl <- Inf
-    } else {
-      kl <- switch(family,
-        "poisson" = (post_alpha - prior_alpha) * digamma(post_alpha) - log(gamma(post_alpha)) + log(gamma(prior_alpha)) + prior_alpha * (log(post_beta) - log(prior_beta)) + post_alpha * ((prior_beta - post_beta) / post_beta),
-        "binomial" = log(beta(prior_alpha, prior_beta) / beta(post_alpha, post_beta)) + (post_alpha - prior_alpha) * digamma(post_alpha) + (post_beta - prior_beta) * digamma(post_beta) + (prior_alpha - post_alpha + prior_beta - post_beta) * digamma(post_alpha + post_beta),
-        "hypergeometric" = log(beta(prior_alpha, prior_beta) / beta(post_alpha, post_beta)) + (post_alpha - prior_alpha) * digamma(post_alpha) + (post_beta - prior_beta) * digamma(post_beta) + (prior_alpha - post_alpha + prior_beta - post_beta) * digamma(post_alpha + post_beta)
-      )
-    }
-  } else {
-    if (any(is.infinite(samples_prior))) {
-      kl <- Inf
-    } else {
-      dens_prior <- .bounded_density(as.numeric(samples_prior))$y
-      prob_prior <- dens_prior / sum(dens_prior)
-      dens_post <- .bounded_density(as.numeric(samples_post))$y
-      prob_post <- dens_post / sum(dens_post)
-      rows <- rbind(prob_post, prob_prior)
-      kl <- suppressMessages({
-        as.numeric(philentropy::KL(rows, unit = "log"))
-      })
-    }
-  }
-  return(kl)
-}
-
 .comp_ub_freq <- function(alternative, conf.level, family, n.obs, x.obs, t.obs, N.units, analytical = TRUE, samples = NULL) {
   if (alternative == "greater") {
     ub <- 1
@@ -616,7 +590,7 @@
       warmup = getOption("mc.warmup", 1000),
       chains = getOption("mc.chains", 4),
       cores = getOption("mc.cores", 1),
-      seed = ceiling(stats::runif(1, -1000, 1000)),
+      seed = sample.int(.Machine$integer.max, 1),
       control = list(adapt_delta = 0.95),
       refresh = 0
     )
@@ -628,7 +602,7 @@
       warmup = getOption("mc.warmup", 1000),
       chains = getOption("mc.chains", 4),
       cores = getOption("mc.cores", 1),
-      seed = ceiling(stats::runif(1, -1000, 1000)),
+      seed = sample.int(.Machine$integer.max, 1),
       control = list(adapt_delta = 0.95),
       refresh = 0
     )
